Enum sixel_sys::MethodForRepColor
[−]
[src]
#[repr(C)]pub enum MethodForRepColor { Auto, CenterOfBox, AverageColor, AveragePixels, }
Method for choosing the a color from the box
Variants
AutoCenterOfBoxAverageColorMethod is described in Heckbert's paper
AveragePixelsTrait Implementations
impl Debug for MethodForRepColor[src]
impl Copy for MethodForRepColor[src]
impl Clone for MethodForRepColor[src]
fn clone(&self) -> MethodForRepColor
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for MethodForRepColor[src]
fn eq(&self, __arg_0: &MethodForRepColor) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.