Enum sixel_sys::Optflag
[−]
[src]
#[repr(u8)]pub enum Optflag { OutFile, UseSevenBitMode, UseEightBitMode, HasGRIArgLimit, NumColors, Mapfile, Monochrome, Insecure, InvertBackground, UseHighColor, UseMacro, MacroNumber, ComplexionScore, IgnoreGIFDelay, StaticGIF, Diffusion, FindLargest, SelectColor, CropRegion, Width, Height, Resampling, QualityMode, LoopMode, PaletteType, BuiltinPalette, EncodingPolicy, BackgroundColor, PenetrateScreen, PipeInput, Verbose, Version, Help, }
Flags used in the easy encoder API.
Flags are the same as the ones used in the img2sixel executable
Variants
OutFileSpecify output file name
UseSevenBitModeUse sixel images for 7 bit terminals or printers
Default of the 2 bit mode flags
UseEightBitModeUse sixel images for 8 bit terminals or printers
HasGRIArgLimitLimit the arguments of DECGRI('!') to 255
NumColorsSpecify the number of colors to reduce the image to
Defaults to 256
Renamed from "SIXEL_OPTFLAG_COLORS"
MapfileGive a file that specifies a set of colors
Transforms the image to match the set
MonochromeOutput a monochrome sixel image
Assumes the terminal background color is black
InsecureConnect to SSL sites without certs
Only applicable if libcurl is used
InvertBackgroundAssume the terminal background color is white
Only applicable when also using Optflag::Monochrome
UseHighColorOutput a 15bpp sixel image
UseMacroUse DECDMAC and DEVINVM sequences to optimize GIF animation rendering
MacroNumberSpecify a macro register number
ComplexionScoreSpecify the number of arguments for the score of complexion correction
Must be 1 or more
IgnoreGIFDelayIgnore delay when rendering GIF animations
StaticGIFRender an animated GIF as a static image
DiffusionChoose a diffusion method to be used with the NumColors option
Should be a DiffusionMethod
FindLargestChoose a method for finding the largest dimension of median cut boxes for splitting
Should be a MethodForLargest
SelectColorChoose the method for selecting the representative color from each median-cut box.
Only makes sense when the Optflag::NumColors is used
Should be a MethodForRepColor
CropRegionCrop a source image to fit some geometry
String format representation is "%dx%d+%d+%d", which is width, height, x, y
WidthResize an image to a specified width
Uses the following syntax:
auto<number>%scale with a percentage<number>scale a number of pixel counts<number>pxscale a number of pixel counts
HeightResize an image to a specified height
Uses the following syntax:
auto<number>%scale with a percentage<number>scale a number of pixel counts<number>pxscale a number of pixel counts
ResamplingChoose a filter for resampling when scaling the image due to
Optflag::Width or Optflag::Height
Should be a ResamplingMethod
QualityModeSelects quality of color quanlization
Should be a QualityMode
LoopModeSelect loop behavior for animated GIFs
Should be a LoopMode
PaletteTypeSelect a palette color space
Should be a PaletteType
BuiltinPaletteChoose a built-in palette type
Should be a BuiltinDither
EncodingPolicyChoose an encoding policy
Should be a EncodePolicy
BackgroundColorSpecify a background color
Represented by the following syntax:
#rgb
#rrggbb
#rrrgggbbb
#rrrrggggbbbb
rgb:r/g/b
rgb:rr/gg/bb
rgb:rrr/ggg/bbb
rgb:rrrr/gggg/bbbb
PenetrateScreenPenetrate GNU Screen using DCS pass-through sequence
PipeInputRead source images from stdin continuously
VerbosePrint debugging info
VersionPrint version and license info
HelpPrint a help message